@@ -1,3 +1,4 @@
+from mrftools import SyntheticSequenceType
 import numpy as np
 import numba
 from numba import jit
@@ -5,8 +6,6 @@ import h5py
 from matplotlib import pyplot as plt
 import nibabel as nib
 from azure.storage.blob import BlobServiceClient, BlobClient, ContainerClient, __version__
-from mrftools import SyntheticSequenceType, DatasetManager, SimpleITKRunner
-import numpy as np
 import tensorflow as tf
 from tensorflow import keras
 import tarfile
@@ -111,7 +110,7 @@ class AISyntheticGenerator:
         self.model.summary()
         return self.model
 
-    def PrepareTrainingData(self, root, subjects, scanners, sets, targetSeries, dataManager:DatasetManager=None, simpleITKRunner:SimpleITKRunner=None, batch_size=5000, fetchFromAzure=True):
+    def PrepareTrainingData(self, root, subjects, scanners, sets, targetSeries, dataManager=None, simpleITKRunner=None, batch_size=5000, fetchFromAzure=True):
         T1_lin = []; T2_lin = []; M0_lin = []; target_lin = []
         if(dataManager == None):
             print("Data Manager object not set.")
